ManualClock

Struct ManualClock 

pub struct ManualClock { /* private fields */ }
A clock whose time is set explicitly, for deterministic tests.

Uses interior mutability so now, set, and advance all take &self.

Implementations

Source

impl ManualClock

pub const fn new(start: u64) -> Self

Creates a clock reading start.

Examples found in repository?
examples/basic.rs (line 11)
9fn main() {
10    // Deterministic clock for tests / demos.
11    let clock = ManualClock::new(0);
12    println!("manual t = {}", clock.now());
13    clock.advance(1_000);
14    println!("after advance(1000): t = {}", clock.now());
15
16    // Real monotonic clock (milliseconds since creation).
17    let real = MonotonicClock::new();
18    let a = real.now();
19    let b = real.now();
20    println!("monotonic: {a} -> {b} (non-decreasing: {})", b >= a);
21
22    // Any &Clock works wherever a Clock is expected.
23    println!("via trait object: {}", read(&clock));
24}
pub fn set(&self, tick: u64)

Sets the clock to tick.

pub fn advance(&self, delta: u64)

Advances the clock by delta (saturating).

Examples found in repository?
examples/basic.rs (line 13)
9fn main() {
10    // Deterministic clock for tests / demos.
11    let clock = ManualClock::new(0);
12    println!("manual t = {}", clock.now());
13    clock.advance(1_000);
14    println!("after advance(1000): t = {}", clock.now());
15
16    // Real monotonic clock (milliseconds since creation).
17    let real = MonotonicClock::new();
18    let a = real.now();
19    let b = real.now();
20    println!("monotonic: {a} -> {b} (non-decreasing: {})", b >= a);
21
22    // Any &Clock works wherever a Clock is expected.
23    println!("via trait object: {}", read(&clock));
24}